#line 2 "bg_lex.lex"
#include "q_shared.h"
#include "bg_lex.h"

#define YY_FATAL_ERROR(msg) bgLexFatalError(msg, yyscanner)
#define UNUSED(x) ((void)(x))



#line 11 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart (FILE *input_file ,yyscan_t yyscanner );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void yypop_buffer_state (yyscan_t yyscanner );

static void yyensure_buffer_stack (yyscan_t yyscanner );
static void yy_load_buffer_state (yyscan_t yyscanner );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *yyalloc (yy_size_t ,yyscan_t yyscanner );
void *yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 63
#define YY_END_OF_BUFFER 64
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[307] =
    {   0,
        0,    0,   64,   62,   60,   61,   62,   55,   56,   62,
        2,   59,    4,   57,   58,   53,   54,    0,    1,    2,
        3,    2,    4,    4,    0,    3,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    5,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    6,    0,    0,    7,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    9,    0,    0,    0,    0,
        0,    0,    0,    0,   21,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    8,   13,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       10,    0,    0,   11,    0,    0,    0,    0,    0,    0,
        0,    0,   22,   23,    0,    0,   25,    0,    0,    0,
        0,    0,    0,    0,   14,    0,   15,    0,    0,    0,
        0,   29,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   12,   17,    0,    0,    0,    0,    0,    0,

        0,    0,   24,   26,   27,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   16,    0,   30,   31,    0,    0,
       33,    0,    0,    0,    0,    0,    0,    0,   18,    0,
       19,    0,    0,    0,    0,   28,   37,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   32,   34,   35,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   20,
        0,   38,   39,    0,    0,   41,    0,    0,    0,    0,
        0,   36,   45,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   40,   42,   43,    0,    0,   46,   47,
        0,    0,   49,    0,    0,    0,    0,    0,   44,   48,

       50,   51,    0,    0,   52,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    1,    1,    1,    1,    1,    6,
        7,    1,    1,    8,    9,   10,    1,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,    1,   12,    1,
        1,    1,    1,    1,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       14,    1,   15,    1,    1,    1,   13,   13,   13,   13,

       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   16,    1,   17,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[18] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[308] =
    {   0,
        0,    0,  364,  703,  703,  703,  358,  703,  703,  350,
        8,  703,    9,  703,  703,  355,  703,  353,  703,   13,
      346,   15,   16,   17,   27,  345,  341,   35,   43,  347,
       51,    0,  339,   59,   67,   23,  345,    0,   75,   29,
        0,  337,   83,  333,   91,   99,  331,  107,  115,   31,
       33,  337,  123,    0,  131,   45,    0,  329,  139,  147,
       46,    0,  326,  161,  169,   40,  332,    0,  323,  177,
      185,   49,   57,  329,  193,    0,  321,  201,  703,  209,
       62,  223,   63,    0,  318,  237,  245,  253,   64,    0,
      317,  267,  275,   73,  323,    0,   68,   78,    0,  315,

      283,  703,  314,  291,  703,  299,   79,  313,  320,  327,
        0,  312,  335,  311,  343,  703,  351,   88,  365,   93,
        0,  309,  379,  387,  703,   92,   94,   96,  103,    0,
      108,  111,    0,  308,  395,  703,  703,  403,  411,  314,
        0,  425,  311,  439,    0,  112,  117,    0,  303,  447,
      703,  300,  455,  703,  463,  119,  477,  305,  491,    0,
      296,  499,  703,  703,  116,  128,  703,  137,  133,  142,
      134,    0,  295,  507,  703,  515,  703,  523,  531,  277,
        0,  703,  144,  149,  151,  158,    0,  153,  163,    0,
      252,  545,  703,  703,  553,  561,  217,    0,  575,  188,

      589,    0,  703,  703,  703,  159,  171,  162,  173,    0,
      180,  597,  141,  605,  703,  613,  703,  703,  181,  179,
      703,  182,  189,  191,  198,    0,  125,  621,  703,  629,
      703,  637,  645,  102,    0,  703,  703,  199,  203,  202,
      206,    0,  211,  218,    0,   77,  659,  703,  703,  703,
      219,  220,  221,  226,    0,   69,  667,   53,  675,  703,
      683,  703,  703,  229,  231,  703,  235,  239,  249,  240,
        0,  703,  703,  251,  254,  255,  256,    0,  257,  265,
        0,   47,  691,  703,  703,  703,  271,  269,  703,  703,
      279,  278,  703,  281,  286,  287,  288,    0,  703,  703,

      703,  703,  296,  301,  703,  703,   20
    } ;

static yyconst flex_int16_t yy_def[308] =
    {   0,
      306,    1,  306,  306,  306,  306,  307,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  307,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,   28,  306,  306,  306,   31,  306,   31,  306,  306,
       34,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,   43,  306,  306,   45,  306,  306,  306,
      306,   48,  306,  306,  306,  306,  306,   53,  306,  306,
      306,  306,  306,  306,  306,   59,  306,  306,  306,  306,
      306,  306,  306,   64,  306,  306,  306,  306,  306,   70,
      306,  306,  306,  306,  306,   75,  306,  306,   78,  306,

      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
       86,  306,  306,  306,  306,  306,  306,  306,  306,  306,
       92,  306,  306,  306,  306,  306,  306,  306,  306,  101,
      306,  306,  104,  306,  306,  306,  306,  306,  306,  306,
      110,  306,  306,  306,  113,  306,  306,  115,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  123,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  135,  306,  306,  306,  306,  306,  306,  306,  306,
      144,  306,  306,  306,  306,  306,  150,  306,  306,  153,
      306,  306,  306,  306,  306,  306,  306,  159,  306,  306,

      306,  162,  306,  306,  306,  306,  306,  306,  306,  174,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  192,  306,  306,  306,  306,
      306,  306,  306,  306,  201,  306,  306,  306,  306,  306,
      306,  212,  306,  306,  214,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  228,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      247,  306,  306,  306,  306,  306,  306,  257,  306,  306,
      259,  306,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  283,  306,  306,

      306,  306,  306,  306,  306,    0,  306
    } ;

static yyconst flex_int16_t yy_nxt[721] =
    {   0,
        4,    5,    6,    5,    7,    8,    9,    4,   10,    4,
       11,   12,   13,   14,   15,   16,   17,   21,   22,   23,
       18,   24,   21,   22,   21,   22,   23,   23,   23,   24,
       25,   44,   49,   45,   49,   27,   51,   28,   29,   50,
       52,   50,   30,   66,   31,   32,   29,   67,   71,   80,
       30,   33,   71,   34,   36,   72,   81,  283,   37,   72,
       73,   38,   39,  259,   74,   80,  106,  117,   40,   41,
       35,   97,   81,  107,  118,   42,   94,   43,   39,  257,
       95,  126,  106,   47,  125,   48,   51,  247,  127,  107,
       52,  117,   53,   54,   55,  126,  155,  126,  118,  128,

       56,   57,   46,  156,  127,  261,  165,   58,  163,   59,
       60,  131,  164,  166,  168,  146,   61,   62,   49,  165,
      183,  169,  155,   63,  167,   64,   66,  184,  182,  156,
       67,  165,  203,   68,   55,  228,  168,  206,  166,   69,
      168,   70,   73,  169,  207,  170,   74,  183,   75,   76,
       60,  214,  183,  204,  185,   77,  188,   78,  205,  184,
      217,  219,  206,   79,   82,  208,  222,  218,  220,  221,
       83,   84,   65,  223,  206,  236,  238,   85,  237,   86,
       88,  207,  219,  239,  219,  222,   89,   90,   71,  220,
      212,  232,  222,   91,  224,   92,   94,  248,  249,  223,

       95,  251,  238,   96,   97,  240,  238,  250,  252,  264,
       98,   99,   80,  239,  243,  262,  265,  100,  263,  101,
      230,  267,  251,  251,  253,  102,   82,  266,  268,  274,
      252,  103,  264,  104,  264,  272,  275,  273,  267,  105,
      108,  265,  267,  287,  109,  284,  110,  111,   87,  268,
      288,  285,  269,  112,  274,  113,   88,  274,  276,  291,
      279,  114,  192,  115,  275,  286,  292,  289,  294,  116,
      119,  290,  287,  293,  287,  295,  120,  121,   93,  288,
      216,  291,  291,  122,  294,  123,  128,  299,  292,  294,
      296,  303,  129,  130,  131,  300,  295,  301,  304,  303,

      132,  133,  106,  302,  303,  174,  162,  134,  195,  135,
      153,  304,  305,  150,  178,  136,  108,  176,  135,  123,
      109,  115,  113,  138,  104,  101,  124,   92,   86,  137,
      139,   78,   93,   70,  140,   87,   64,  141,  142,   59,
       65,   48,  143,   45,  144,  145,  146,   43,   46,   34,
       35,   28,  147,  148,  117,   26,   26,   19,   25,  149,
       20,  150,   19,  306,  306,  306,  306,  151,  119,  306,
      306,  306,  306,  152,  306,  153,  306,  306,  306,  306,
      306,  154,  157,  306,  306,  306,  158,  306,  159,  160,
      124,  306,  306,  306,  306,  161,  306,  162,  170,  306,

      306,  306,  306,  306,  171,  172,  138,  306,  306,  306,
      306,  173,  306,  174,  139,  306,  306,  306,  140,  306,
      306,  306,  306,  306,  306,  306,  306,  175,  142,  306,
      306,  306,  143,  306,  306,  306,  306,  306,  306,  306,
      306,  177,  179,  306,  306,  306,  180,  306,  306,  181,
      185,  306,  306,  306,  306,  306,  186,  187,  188,  306,
      306,  306,  306,  306,  189,  190,  155,  306,  306,  306,
      306,  191,  306,  192,  306,  306,  306,  306,  306,  193,
      157,  306,  306,  306,  158,  306,  306,  306,  306,  306,
      306,  306,  306,  194,  196,  306,  306,  306,  197,  306,

      306,  198,  199,  306,  306,  306,  200,  306,  201,  202,
      208,  306,  306,  306,  306,  306,  209,  210,  176,  306,
      306,  306,  306,  211,  306,  212,  178,  306,  306,  306,
      306,  213,  306,  214,  179,  306,  306,  306,  180,  306,
      306,  306,  306,  306,  306,  306,  306,  215,  224,  306,
      306,  306,  306,  306,  225,  226,  195,  306,  306,  306,
      306,  227,  306,  228,  196,  306,  306,  306,  197,  306,
      306,  306,  306,  306,  306,  306,  306,  229,  199,  306,
      306,  306,  200,  306,  306,  306,  306,  306,  306,  306,
      306,  231,  233,  306,  306,  306,  234,  306,  306,  235,

      240,  306,  306,  306,  306,  306,  241,  242,  243,  306,
      306,  306,  306,  306,  244,  245,  216,  306,  306,  306,
      306,  246,  306,  247,  253,  306,  306,  306,  306,  306,
      254,  255,  230,  306,  306,  306,  306,  256,  306,  257,
      232,  306,  306,  306,  306,  258,  306,  259,  233,  306,
      306,  306,  234,  306,  306,  306,  306,  306,  306,  306,
      306,  260,  269,  306,  306,  306,  306,  306,  270,  271,
      276,  306,  306,  306,  306,  306,  277,  278,  279,  306,
      306,  306,  306,  306,  280,  281,  261,  306,  306,  306,
      306,  282,  306,  283,  296,  306,  306,  306,  306,  306,

      297,  298,    3,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306
    } ;

static yyconst flex_int16_t yy_chk[721] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,   11,   11,   13,
      307,   13,   20,   20,   22,   22,   23,   24,   23,   24,
       25,   36,   40,   36,   50,   25,   51,   25,   28,   40,
       51,   50,   28,   66,   28,   28,   29,   66,   56,   61,
       29,   29,   72,   29,   31,   56,   61,  282,   31,   72,
       73,   31,   34,  258,   73,   81,   83,   89,   34,   34,
       35,   97,   81,   83,   89,   35,   94,   35,   39,  256,
       94,   98,  107,   39,   97,   39,   43,  246,   98,  107,
       43,  118,   43,   43,   45,  126,  120,  127,  118,  128,

       45,   45,   46,  120,  127,  234,  129,   46,  126,   46,
       48,  131,  128,  129,  132,  146,   48,   48,   49,  165,
      147,  132,  156,   49,  131,   49,   53,  147,  146,  156,
       53,  166,  165,   53,   55,  227,  169,  171,  166,   55,
      168,   55,   59,  169,  171,  170,   59,  183,   59,   59,
       60,  213,  184,  168,  185,   60,  188,   60,  170,  184,
      183,  186,  206,   60,   64,  208,  189,  185,  186,  188,
       64,   64,   65,  189,  207,  206,  209,   65,  208,   65,
       70,  207,  220,  209,  219,  222,   70,   70,   71,  220,
      211,  200,  223,   71,  224,   71,   75,  219,  222,  223,

       75,  225,  238,   75,   78,  240,  239,  224,  225,  241,
       78,   78,   80,  239,  243,  238,  241,   80,  240,   80,
      197,  244,  251,  252,  253,   80,   82,  243,  244,  254,
      252,   82,  264,   82,  265,  251,  254,  253,  267,   82,
       86,  265,  268,  270,   86,  264,   86,   86,   87,  268,
      270,  267,  269,   87,  274,   87,   88,  275,  276,  277,
      279,   88,  191,   88,  275,  269,  277,  274,  280,   88,
       92,  276,  288,  279,  287,  280,   92,   92,   93,  288,
      180,  292,  291,   93,  294,   93,  101,  287,  292,  295,
      296,  297,  101,  101,  104,  291,  295,  294,  297,  303,

      104,  104,  106,  296,  304,  173,  161,  106,  158,  106,
      152,  304,  303,  149,  143,  106,  108,  140,  134,  122,
      108,  114,  112,  109,  103,  100,   95,   91,   85,  108,
      110,   77,   74,   69,  110,   67,   63,  110,  113,   58,
       52,   47,  113,   44,  113,  113,  115,   42,   37,   33,
       30,   27,  115,  115,  117,   26,   21,   18,   16,  117,
       10,  117,    7,    3,    0,    0,    0,  117,  119,    0,
        0,    0,    0,  119,    0,  119,    0,    0,    0,    0,
        0,  119,  123,    0,    0,    0,  123,    0,  123,  123,
      124,    0,    0,    0,    0,  124,    0,  124,  135,    0,

        0,    0,    0,    0,  135,  135,  138,    0,    0,    0,
        0,  138,    0,  138,  139,    0,    0,    0,  139,    0,
        0,    0,    0,    0,    0,    0,    0,  139,  142,    0,
        0,    0,  142,    0,    0,    0,    0,    0,    0,    0,
        0,  142,  144,    0,    0,    0,  144,    0,    0,  144,
      150,    0,    0,    0,    0,    0,  150,  150,  153,    0,
        0,    0,    0,    0,  153,  153,  155,    0,    0,    0,
        0,  155,    0,  155,    0,    0,    0,    0,    0,  155,
      157,    0,    0,    0,  157,    0,    0,    0,    0,    0,
        0,    0,    0,  157,  159,    0,    0,    0,  159,    0,

        0,  159,  162,    0,    0,    0,  162,    0,  162,  162,
      174,    0,    0,    0,    0,    0,  174,  174,  176,    0,
        0,    0,    0,  176,    0,  176,  178,    0,    0,    0,
        0,  178,    0,  178,  179,    0,    0,    0,  179,    0,
        0,    0,    0,    0,    0,    0,    0,  179,  192,    0,
        0,    0,    0,    0,  192,  192,  195,    0,    0,    0,
        0,  195,    0,  195,  196,    0,    0,    0,  196,    0,
        0,    0,    0,    0,    0,    0,    0,  196,  199,    0,
        0,    0,  199,    0,    0,    0,    0,    0,    0,    0,
        0,  199,  201,    0,    0,    0,  201,    0,    0,  201,

      212,    0,    0,    0,    0,    0,  212,  212,  214,    0,
        0,    0,    0,    0,  214,  214,  216,    0,    0,    0,
        0,  216,    0,  216,  228,    0,    0,    0,    0,    0,
      228,  228,  230,    0,    0,    0,    0,  230,    0,  230,
      232,    0,    0,    0,    0,  232,    0,  232,  233,    0,
        0,    0,  233,    0,    0,    0,    0,    0,    0,    0,
        0,  233,  247,    0,    0,    0,    0,    0,  247,  247,
      257,    0,    0,    0,    0,    0,  257,  257,  259,    0,
        0,    0,    0,    0,  259,  259,  261,    0,    0,    0,
        0,  261,    0,  261,  283,    0,    0,    0,    0,    0,

      283,  283,  306,  306,  306,  306,  306,  306,  306,  306,
      306,  306,  306,  306,  306,  306,  306,  306,  306,  306
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "bg_lex.lex"

#line 705 "lex.yy.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE bgLexMorphem*

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (yyscan_t yyscanner );

int yyget_debug (yyscan_t yyscanner );

void yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra (yyscan_t yyscanner );

void yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *yyget_in (yyscan_t yyscanner );

void yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *yyget_out (yyscan_t yyscanner );

void yyset_out  (FILE * out_str ,yyscan_t yyscanner );

int yyget_leng (yyscan_t yyscanner );

char *yyget_text (yyscan_t yyscanner );

int yyget_lineno (yyscan_t yyscanner );

void yyset_lineno (int line_number ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (yyscan_t yyscanner );
#else
extern int yywrap (yyscan_t yyscanner );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  ,yyscan_t yyscanner);
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 18 "bg_lex.lex"

#line 931 "lex.yy.c"

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 307 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 703 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 19 "bg_lex.lex"
{
	char *s = yytext; s++;
	yyextra->type = LMT_STRING;
	yyextra->data.str = malloc(strlen(yytext) - 1);
	memset(yyextra->data.str, 0, strlen(yytext) - 1);
	strncpy(yyextra->data.str, s, strlen(yytext) - 2);
	yyextra->column += strlen(yytext);
	return LMT_STRING;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 28 "bg_lex.lex"
{
	yyextra->type = LMT_INT;
	yyextra->data.numInteger = atoi(yytext);
	yyextra->column += strlen(yytext);
	return LMT_INT;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 34 "bg_lex.lex"
{
	yyextra->type = LMT_DOUBLE;
	yyextra->data.numDouble = atof(yytext);
	yyextra->column += strlen(yytext);
	return LMT_DOUBLE;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 40 "bg_lex.lex"
{
	yyextra->type = LMT_SYMBOL;
	yyextra->data.symbol = bgLex_textToSymbol(yytext);
	yyextra->column += strlen(yytext);
	return LMT_SYMBOL;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 46 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf %lf %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 57 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf %lf %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 67 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf %lf %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 77 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf %lf %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 87 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf %lf %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 97 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf %lf %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 107 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf %lf %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 117 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf %lf %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 127 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf, %lf, %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 138 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf, %lf, %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 148 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf, %lf, %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 158 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf, %lf, %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 168 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf, %lf, %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 178 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf, %lf, %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 188 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf, %lf, %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 198 "bg_lex.lex"
{
	double a, b, c;
	sscanf(yytext, "{ %lf, %lf, %lf }", &a, &b, &c);
	yyextra->data.vector3[0] = a;
	yyextra->data.vector3[1] = b;
	yyextra->data.vector3[2] = c;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR3;
	return LMT_VECTOR3;
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 208 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 219 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 230 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 241 "bg_lex.lex"
{ 
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 252 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 263 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 274 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 285 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 296 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 307 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 318 "bg_lex.lex"
{ 
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 329 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 340 "bg_lex.lex"
{ 
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 351 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 362 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 373 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf %lf %lf %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 384 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 395 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 406 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 417 "bg_lex.lex"
{ 
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 428 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 439 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 450 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 461 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 472 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 483 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 494 "bg_lex.lex"
{ 
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 505 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 516 "bg_lex.lex"
{ 
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 527 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 538 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 549 "bg_lex.lex"
{
	double a, b, c, d;
	sscanf(yytext, "{ %lf, %lf, %lf, %lf }", &a, &b, &c, &d);
	yyextra->data.vector4[0] = a;
	yyextra->data.vector4[1] = b;
	yyextra->data.vector4[2] = c;
	yyextra->data.vector4[3] = d;
	yyextra->column += strlen(yytext);
	yyextra->type = LMT_VECTOR4;
	return LMT_VECTOR4;
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 560 "bg_lex.lex"
{
	yyextra->type = LMT_SYMBOL;
	yyextra->data.symbol = LSYM_OBRACEC;
	yyextra->column++;
	return LMT_SYMBOL;
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 566 "bg_lex.lex"
{
	yyextra->type = LMT_SYMBOL;
	yyextra->data.symbol = LSYM_CBRACEC;
	yyextra->column++;
	return LMT_SYMBOL;
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 572 "bg_lex.lex"
{
	yyextra->type = LMT_SYMBOL;
	yyextra->data.symbol = LSYM_OBRACE;
	yyextra->column++;
	return LMT_SYMBOL;
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 578 "bg_lex.lex"
{
	yyextra->type = LMT_SYMBOL;
	yyextra->data.symbol = LSYM_CBRACE;
	yyextra->column++;
	return LMT_SYMBOL;
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 584 "bg_lex.lex"
{
	yyextra->type = LMT_SYMBOL;
	yyextra->data.symbol = LSYM_OBRACESQ;
	yyextra->column++;
	return LMT_SYMBOL;
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 590 "bg_lex.lex"
{
	yyextra->type = LMT_SYMBOL;
	yyextra->data.symbol = LSYM_CBRACESQ;
	yyextra->column++;
	return LMT_SYMBOL;
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 596 "bg_lex.lex"
{
	yyextra->type = LMT_SYMBOL;
	yyextra->data.symbol = LSYM_SEMICOLON;
	yyextra->column++;
	return LMT_SYMBOL;
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 602 "bg_lex.lex"
{
	yyextra->column++;
	yyextra->type = LMT_IGNORE;
	return LMT_IGNORE;
}
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
#line 607 "bg_lex.lex"
{
	yyextra->line++;
	yyextra->column = 0;
	yyextra->type = LMT_IGNORE;
	return LMT_IGNORE;
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 613 "bg_lex.lex"
{
	yyextra->column++;
	yyextra->type = LMT_IGNORE;
	return LMT_IGNORE;
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 618 "bg_lex.lex"
ECHO;
	YY_BREAK
#line 1866 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 307 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 307 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 306);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp , yyscan_t yyscanner)
{
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = yyg->yy_n_chars + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf ,yyscanner );

	yyfree((void *) b ,yyscanner );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_lineno called with no buffer" , yyscanner); 
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_column called with no buffer" , yyscanner); 
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */

int yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 618 "bg_lex.lex"



#ifdef LEX_TEXT
int main(int argc, char* argv[]) {
	char buff[4096];
	yyscan_t scanner;
	FILE* f;
	bgLex* lex;

	f = fopen("test.txt", "r");
	fread(buff, 4096, 1, f);
	fclose(f);
  
	lex = bgLex_create(buff);
	while(bgLex_lex(lex)) {
		printf("type=%i symbol=%i yytext=%s\n", lex->morphem.type, lex->morphem.data.symbol, yyget_text(lex->lex));
	}
	bgLex_destroy(lex);

	return EXIT_SUCCESS;
}
#endif

bgLex* bgLex_create(char* data) {
	bgLex* l = malloc(sizeof(bgLex));

	/* HACK HACK HACK ... get rid of some compiler warnings */
	UNUSED(yyunput);
	UNUSED(input);

	if(l != NULL) {
		l->morphem = malloc(sizeof(bgLexMorphemData));

		if(l->morphem == NULL) {
			free(l);
			return NULL;
		}

		l->morphem->line = 0;
		l->morphem->column = 0;

		yylex_init_extra(l->morphem,&l->lex);
		l->buf = yy_scan_string(data,l->lex);
	}

	return l;
}

void bgLex_destroy(bgLex* lex) {
	if(lex == NULL) {
		return;
	}

	if(lex->buf != NULL) {
		yy_delete_buffer(lex->buf,lex->lex);
	}

	if(lex->lex != NULL) {
		yylex_destroy(lex->lex);
	}

	if(lex->morphem != NULL) {
		free(lex->morphem);
	}

	free(lex);
}

int bgLex_lex(bgLex* lex) {
	int res;

	if(lex->morphem->data.str != NULL) {
		free(lex->morphem->data.str);
	}

	/* skip LMT_IGNORE */
	while(1) {
		res = yylex(lex->lex);
		if(lex->morphem->type != LMT_IGNORE) {
			break;
		}
	}

	return res;
}

bgLexSymbol bgLex_textToSymbol(char* text) {
	if(strcmp("ServerChangeConfig", text) == 0) {
		return LSYM_SERVER_CHANGE_CONFIG;
	}

	if(strcmp("Server", text) == 0) {
		return LSYM_SERVER;
	}

	if(strcmp("HolodeckData", text) == 0) {
		return LSYM_HOLODECK_DATA;
	}

	if(strcmp("Program", text) == 0) {
		return LSYM_PROGRAM;
	}

	if(strcmp("MapChangeConfig", text) == 0) {
		return LSYM_MAP_CHANGE_CONFIG;
	}

	if(strcmp("Map", text) == 0) {
		return LSYM_MAP;
	}

	if(strcmp("LocationsList2", text) == 0) {
		return LSYM_LOCATIONS_LIST_2;
	}

	if(strcmp("LocationsList", text) == 0) {
		return LSYM_LOCATIONS_LIST;
	}

	if(strcmp("message", text) == 0) {
		return LSYM_MESSAGE;
	}

	if(strcmp("consoleName", text) == 0) {
		return LSYM_CONSOLE_NAME;
	}

	if(strcmp("formalName", text) == 0) {
		return LSYM_FORMAL_NAME;
	}

	if(strcmp("radarColor", text) == 0) {
		return LSYM_RADAR_COLOR;
	}

	if(strcmp("iconColor", text) == 0) {
		return LSYM_ICON_COLOR;
	}

	if(strcmp("NULL", text) == 0) {
		return LSYM_NULL;
	}

	if(strcmp("modelSkin", text) == 0) {
		return LSYM_MODEL_SKIN;
	}

	if(strcmp("weapons", text) == 0) {
		return LSYM_WEAPONS;
	}

	if(strcmp("hasRanks", text) == 0) {
		return LSYM_HAS_RANKS;
	}

	if(strcmp("teal", text) == 0) {
		return LSYM_TEAL;
	}

	if(strcmp("medical", text) == 0) {
		return LSYM_MEDICAL;
	}

	if(strcmp("gold", text) == 0) {
		return LSYM_GOLD;
	}

	if(strcmp("green", text) == 0) {
		return LSYM_GREEN;
	}

	if(strcmp("marine", text) == 0) {
		return LSYM_MARINE;
	}

	if(strcmp("red", text) == 0) {
		return LSYM_RED;
	}

	if(strcmp("WP_TRICORDER", text) == 0) {
		return LSYM_WP_TRICORDER;
	}

	if(strcmp("WP_PADD", text) == 0) {
		return LSYM_WP_PADD;
	}

	if(strcmp("WP_COFFEE", text) == 0) {
    return LSYM_WP_COFFEE;
	}

	if(strcmp("WP_PHASER", text) == 0) {
		return LSYM_WP_PHASER;
	}

	if(strcmp("WP_COMPRESSION_RIFLE", text) == 0) {
		return LSYM_WP_COMPRESSION_RIFLE;
	}

	if(strcmp("WP_TR116", text) == 0) {
		return LSYM_WP_TR116;
	}

	if(strcmp("WP_GRENADE_LAUNCHER", text) == 0) {
		return LSYM_WP_GRENADE_LAUNCHER;
	}

	if(strcmp("WP_QUANTUM_BURST", text) == 0) {
		return LSYM_WP_QUANTUM_BURST;
	}

	if(strcmp("WP_MEDKIT", text) == 0) {
		return LSYM_WP_MEDKIT;
	}

	if(strcmp("WP_VOYAGER_HYPO", text) == 0) {
		return LSYM_WP_VOYAGER_HYPO;
	}

	if(strcmp("WP_DERMAL_REGEN", text) == 0) {
		return LSYM_WP_DERMAL_REGEN;
	}

	if(strcmp("WP_TOOLKIT", text) == 0) {
		return LSYM_WP_TOOLKIT;
	}

	if(strcmp("WP_HYPERSPANNER", text) == 0) {
		return LSYM_WP_HYPERSPANNER;
	}

	if(strcmp("WP_DISRUPTOR", text) == 0) {
		return LSYM_WP_DISRUPTOR;
	}

	if(strcmp("WP_NULL", text) == 0) {
		return LSYM_WP_NULL;
	}

	if(strcmp("WP_NULL_HANDS", text) == 0) {
		return LSYM_WP_NULL_HANDS;
	}

	if(strcmp("WP_0", text) == 0) {
		return LSYM_WP_0;
	}

	if(strcmp("WP_1", text) == 0) {
		return LSYM_WP_1;
	}

	if(strcmp("WP_2", text) == 0) {
		return LSYM_WP_2;
	}

	if(strcmp("WP_3", text) == 0) {
		return LSYM_WP_3;
	}

	if(strcmp("WP_4", text) == 0) {
		return LSYM_WP_4;
	}

	if(strcmp("WP_5", text) == 0) {
		return LSYM_WP_5;
	}

	if(strcmp("WP_6", text) == 0) {
		return LSYM_WP_6;
	}

	if(strcmp("WP_7", text) == 0) {
		return LSYM_WP_7;
	}

	if(strcmp("WP_8", text) == 0) {
		return LSYM_WP_8;
	}

	if(strcmp("WP_9", text) == 0) {
		return LSYM_WP_9;
	}

	if(strcmp("WP_10", text) == 0) {
		return LSYM_WP_10;
	}

	if(strcmp("WP_11", text) == 0) {
		return LSYM_WP_11;
	}

	if(strcmp("WP_12", text) == 0) {
		return LSYM_WP_12;
	}

	if(strcmp("WP_13", text) == 0) {
		return LSYM_WP_13;
	}

	if(strcmp("WP_14", text) == 0) {
		return LSYM_WP_14;
	}

	if(strcmp("WP_15", text) == 0) {
		return LSYM_WP_15;
	}

	if(strcmp("admin", text) == 0) {
		return LSYM_ADMIN;
	}

	if(strcmp("borg", text) == 0) {
		return LSYM_BORG;
	}

	if(strcmp("n00b", text) == 0) {
		return LSYM_N00B;
	}

	if(strcmp("noShow", text) == 0) {
		return LSYM_NO_SHOW;
	}

	if(strcmp("MenuTextureDef", text) == 0) {
		return LSYM_MENU_TEXTURE_DEF;
	}

	if(strcmp("ConsoleName", text) == 0) {
		return LSYM_CONSOLE_NAME;
	}

	if(strcmp("FormalName", text) == 0) {
		return LSYM_FORMAL_NAME;
	}

	if(strcmp("MenuTextureRed", text) == 0) {
		return LSYM_MENU_TEXTURE_RED;
	}

	if(strcmp("MenuTextureTeal", text) == 0) {
		return LSYM_MENU_TEXTURE_TEAL;
	}

	if(strcmp("MenuTextureGold", text) == 0) {
		return LSYM_MENU_TEXTURE_GOLD;
	}

	if(strcmp("MenuTextureGreen", text) == 0) {
		return LSYM_MENU_TEXTURE_GREEN;
	}

	if(strcmp("BoltModel", text) == 0) {
		return LSYM_BOLT_MODEL;
	}

	if(strcmp("BoltShader", text) == 0) {
		return LSYM_BOLT_SHADER;
	}

	if(strcmp("AdmiralRank", text) == 0) {
		return LSYM_ADMIRAL_RANK;
	}

	if(strcmp("true", text) == 0) {
		return LSYM_TRUE;
	}

	if(strcmp("false", text) == 0) {
		return LSYM_FALSE;
	}

	return LSYM_UNKNOWN;
}

void bgLexFatalError(const char* msg, void* lex) {
	Com_Printf("LEXER ERROR: %s\n", msg);
}


